@@ -26,12 +26,14 @@
 #include "xgetcwd.c"
 #include "xmkdir.c"
 #include "xreadlink.c"
+#include "xregex.c"
 #include "xsystem.c"
 
 /* custom libs */
 #include "atom_explode.c"
 #include "atom_compare.c"
 #include "basename.c"
+#include "prelink.c"
 
 #ifndef _LIB_Q
 # include "profile.c"
