@@ -1,7 +1,7 @@
 /*
  * Copyright 2005-2008 Gentoo Foundation
  * Distributed under the terms of the GNU General Public License v2
- * $Header: /var/cvsroot/gentoo-projects/portage-utils/main.c,v 1.192 2011/03/17 03:19:50 vapier Exp $
+ * $Header: /var/cvsroot/gentoo-projects/portage-utils/main.c,v 1.195 2011/10/03 01:25:54 vapier Exp $
  *
  * Copyright 2005-2008 Ned Ludd        - <solar@gentoo.org>
  * Copyright 2005-2008 Mike Frysinger  - <vapier@gentoo.org>
@@ -11,9 +11,6 @@
 #ifdef _AIX
 #define _LINUX_SOURCE_COMPAT
 #endif
-#ifndef _q_static
-# define _q_static static
-#endif
 
 #include <stdarg.h>
 #include <stdio.h>
@@ -122,7 +119,7 @@ void no_colors()
 	NULL
 #define COMMON_GETOPTS_CASES(applet) \
 	case 'v': ++verbose; break; \
-	case 'q': { FILE *dummy; ++quiet; dummy = freopen("/dev/null", "w", stderr); break; } \
+	case 'q': ++quiet; if (freopen("/dev/null", "w", stderr)); break; \
 	case 'V': version_barf( applet ## _rcsid ); break; \
 	case 'h': applet ## _usage(EXIT_SUCCESS); break; \
 	case 'C': no_colors(); break; \
@@ -288,14 +285,8 @@ int rematch(const char *re, const char *match, int cflags)
 	if ((match == NULL) || (re == NULL))
 		return EXIT_FAILURE;
 
-	if ((ret = regcomp(&preg, re, cflags))) {
-		char err[256];
-		if (regerror(ret, &preg, err, sizeof(err)))
-			warnf("regcomp failed: %s", err);
-		else
-			warnf("regcomp failed");
+	if (wregcomp(&preg, re, cflags))
 		return EXIT_FAILURE;
-	}
 	ret = regexec(&preg, match, 0, NULL, 0);
 	regfree(&preg);
 
